#
# spec file for package ethumb
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ethumb
Version:        1.7.4
Release:        1.1
License:        LGPL-2.1
Summary:        Thumbnail generation library for EFL
Url:            http://enlightenment.org/
Group:          Development/Libraries/C and C++
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  doxygen
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  e_dbus-devel >= %version
BuildRequires:  ecore-devel >= %version
BuildRequires:  edje-devel >= %version
BuildRequires:  eina-devel >= %version
BuildRequires:  emotion-devel >= %version
BuildRequires:  evas-devel >= %version
BuildRequires:  libexif-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ethumb is a thumbnail generation library. Part of Enlightenment Foundation Libraries.

%package devel
Summary:        Ethumb development package
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       e_dbus-devel >= %version
Requires:       ecore-devel >= %version
Requires:       edje-devel >= %version
Requires:       eina-devel >= %version
Requires:       emotion-devel >= %version
Requires:       evas-devel >= %version
Requires:       libethumb1 = %{version}
Requires:       libethumb_client1 = %{version}
Requires:       libexif-devel

%description devel
Development files for Ethumb package.

%package -n libethumb1
Summary:        Shared library of ethumb
Group:          System/Libraries

%description -n libethumb1
Main shared library of package ethumb.

%package -n libethumb_client1
Summary:        Shared library of ethumb client
Group:          System/Libraries

%description -n libethumb_client1
Shared library used by ethumb client.

%package doc-html
Summary:        HTML documentation of Ethumb
Group:          Documentation/HTML

%description doc-html
Documentation of Ethumb library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Ethumb
Group:          Documentation/Man

%description doc-man
Documentation of Ethumb library in form of man pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static --disable-silent-rules
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}/html
/bin/cp -vr doc/html/* %{buildroot}%{_docdir}/%{name}/html/
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif
cp COPYING README %{buildroot}%{_docdir}/%{name}/

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;

%clean
%{?buildroot:rm -rf %{buildroot}}

%post -n libethumb1 -p /sbin/ldconfig

%postun -n libethumb1 -p /sbin/ldconfig

%post -n libethumb_client1 -p /sbin/ldconfig

%postun -n libethumb_client1 -p /sbin/ldconfig

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir}/*.so

%files -n libethumb1
%defattr(-,root,root)
%{_libdir}/libethumb.so.*

%files -n libethumb_client1
%defattr(-,root,root)
%{_libdir}/libethumb_client.so.*

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/html
%{_bindir}/*
%{_libdir}/ethumb/
%{_datadir}/ethumb
%{_libexecdir}/ethumbd_slave
%{_datadir}/dbus-1/services/org.enlightenment.Ethumb.service

%files doc-html
%defattr(-, root, root)
%doc %{_docdir}/%{name}/html/

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-1.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Ethumb 1.7.3:
  * Add XML output to doc
  * Add installation rule for doc
* Fri Dec 21 2012 sleep_walker@suse.cz
- use vicious %%doc macro again, but now it will work, I promise
* Fri Dec 21 2012 sleep_walker@suse.cz
- remove vicious %%doc macro
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Wed Nov 28 2012 sleep_walker@suse.cz
- 0001-ethumb-Fix-license-on-ethumbd.c-too.patch:
  fix license inconsistency - part 2
  taken from SVN, rev. 79756 (bnc#791455)
* Tue Nov 27 2012 sleep_walker@suse.cz
- 0001-Ethumb-Fix-license-reporting-on-executables-s-versio.patch:
  fix license inconsistency - part 1
  taken from SVN, rev. 79748 (bnc#791455)
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Sat Nov 24 2012 sleep_walker@suse.cz
- minor change in files section
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
- 1.7.2 is required to build and use the latest e17 alpha's
* Thu Nov 22 2012 sleep_walker@suse.cz
- simplify build
* Thu Nov 22 2012 sleep_walker@suse.cz
- remove conditions for SLE 10 as we don't build for it anymore
- fix license
- clean up the spec file
- remove autoupdate entries from changelog
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Mon Jun 11 2012 pgajdos@suse.com
- fixed filelist in libethumb1
* Wed Jun  6 2012 pgajdos@suse.com
- remove epdf-devel dependency
* Thu Mar 29 2012 sleep_walker@suse.cz
- update to version 1.0.0
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Wed Nov  2 2011 tcech@suse.com
- fix dependencies for devel package for SLE10
* Wed Nov  2 2011 sleep_walker@suse.cz
- fix dependencies for devel package
* Wed Nov  2 2011 sleep_walker@suse.cz
- dbus path fixed all but suse
* Wed Nov  2 2011 tcech@suse.com
- fix build when e_dbus is not available
* Wed Nov  2 2011 tcech@suse.com
- workaround dbus service path
* Wed Nov  2 2011 tcech@suse.com
- initial commit
